"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Dropdown = void 0;
const react_1 = __importDefault(require("react"));
const styled_components_1 = require("styled-components");
const SortIcon_1 = require("../icons/SortIcon");
const ArrowDownIcon_1 = require("../icons/ArrowDownIcon");
const ArrowUpIcon_1 = __importDefault(require("../icons/ArrowUpIcon"));
const CalendarIcon_1 = require("../icons/CalendarIcon");
const DropdownWrapper = styled_components_1.styled.div `
  position: relative;
  display: inline-block;
  width: 100%;
`;
const DropdownButton = styled_components_1.styled.button `
  box-sizing: border-box;
  display: flex;
  flex-direction: row;
  align-items: center;
  padding: 6px 6px 6px 10px;
  gap: 2px;
  width: 100%;
  height: 32px;
  font-size: 14px;
  font-family: "Inter", sans-serif;
  background: ${({ $darkmode }) => ($darkmode ? "#0E121B" : "#FFFFFF")};
  border: 1px solid ${({ $darkmode }) => ($darkmode ? "#2B303B" : "#E1E4EA")};
  box-shadow: 0px 1px 2px rgba(10, 13, 20, 0.03);
  border-radius: 8px;
  color: ${({ $darkmode }) => ($darkmode ? "#E1E4EA" : "#525866")};
  cursor: pointer;
  transition: all 0.2s;
  justify-content: space-between;

  &:hover {
    border-color: ${({ $darkmode }) => ($darkmode ? "#666" : "#aaa")};
  }
`;
const DropdownMenu = styled_components_1.styled.ul `
  position: absolute;
  top: 100%;
  left: 0;
  width: 100%;
  background: ${({ $darkmode }) => ($darkmode ? "#0E121B" : "#FFFFFF")};
  border: 1px solid ${({ $darkmode }) => ($darkmode ? "#2B303B" : "#E1E4EA")};
  box-shadow: 0px 2px 5px rgba(10, 13, 20, 0.1);
  border-radius: 8px;
  padding: 5px 0;
  list-style: none;
  margin-top: 4px;
  display: ${({ $open }) => ($open ? "block" : "none")};
  z-index: 10;
`;
const DropdownItem = styled_components_1.styled.li `
  padding: 8px 10px;
  font-size: 14px;
  font-family: "Inter", sans-serif;
  color: ${({ $darkmode }) => ($darkmode ? "#E1E4EA" : "#525866")};
  cursor: pointer;
  transition: background 0.2s;

  &:hover {
    background: ${({ $darkmode }) => ($darkmode ? "#2B303B" : "#f1f1f1")};
  }
`;
const IconWrapper = styled_components_1.styled.span `
  display: flex;
  margin-right: 5px;
  align-items: center;
`;
const Dropdown = ({ options, defaultLabel = "Select", icon = "none", darkmode = false, }) => {
    const [isOpen, setIsOpen] = react_1.default.useState(false);
    const [selected, setSelected] = react_1.default.useState(defaultLabel);
    const toggleDropdown = () => setIsOpen(!isOpen);
    const handleSelect = (option) => {
        setSelected(option);
        setIsOpen(false);
    };
    return (react_1.default.createElement(DropdownWrapper, { "$darkmode": darkmode },
        react_1.default.createElement(DropdownButton, { onClick: toggleDropdown, "$darkmode": darkmode },
            react_1.default.createElement("div", { style: { display: "flex", alignItems: "center" } },
                icon === "sort" && (react_1.default.createElement(IconWrapper, null,
                    react_1.default.createElement(SortIcon_1.SortIcon, null))),
                icon === "calendar" && (react_1.default.createElement(IconWrapper, null,
                    react_1.default.createElement(CalendarIcon_1.CalendarIcon, null))),
                selected),
            isOpen ? react_1.default.createElement(ArrowUpIcon_1.default, { color: "gray" }) : react_1.default.createElement(ArrowDownIcon_1.ArrowDownIcon, { color: "gray" })),
        react_1.default.createElement(DropdownMenu, { "$darkmode": darkmode, "$open": isOpen }, options.map((option) => (react_1.default.createElement(DropdownItem, { key: option, onClick: () => handleSelect(option), "$darkmode": darkmode }, option))))));
};
exports.Dropdown = Dropdown;
