"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UploadImage = void 0;
const react_1 = __importDefault(require("react"));
const styled_components_1 = __importDefault(require("styled-components"));
const UploadContainer = styled_components_1.default.div `
  display: flex;
  flex-direction: row;
  align-items: flex-start;
  gap: 20px;
  width: 352px;
  height: 92px;
`;
const ImagePreview = styled_components_1.default.div `
  width: 56px;
  height: 56px;
  border-radius: 50%;
  background: ${({ $imageUrl }) => $imageUrl ? `url(${$imageUrl})` : "#F0F2F5"}
    no-repeat center/cover;
  display: flex;
  align-items: center;
  justify-content: center;
`;
const InfoWrapper = styled_components_1.default.div `
  display: flex;
  flex-direction: column;
`;
const Title = styled_components_1.default.div `
  font-family: "Inter", sans-serif;
  font-weight: 500;
  font-size: 16px;
  line-height: 24px;
  color: ${({ $darkmode }) => ($darkmode ? "#FFFFFF" : "#0E121B")};
  transition: color 0.2s ease-in-out;
`;
const Subtitle = styled_components_1.default.div `
  font-family: "Inter", sans-serif;
  font-weight: 400;
  font-size: 14px;
  line-height: 20px;
  color: #525866;
  margin-bottom: 6px;
`;
const UploadButton = styled_components_1.default.label `
  box-sizing: border-box;
  display: flex;
  flex-direction: row;
  justify-content: center;
  align-items: center;
  padding: 6px;
  gap: 2px;
  width: 68px;
  height: 32px;
  background: #ffffff;
  border: 1px solid #e1e4ea;
  box-shadow: 0px 1px 2px rgba(10, 13, 20, 0.03);
  border-radius: 8px;
  font-size: 14px;
  cursor: pointer;
  transition: 0.2s;

  &:hover {
    border-color: #ccc;
  }
`;
const HiddenInput = styled_components_1.default.input `
  display: none;
`;
const UploadImage = ({ darkmode = false, onFileSelect, }) => {
    const [image, setImage] = react_1.default.useState(null);
    const handleImageUpload = (event) => {
        var _a;
        const uploadedFile = (_a = event.target.files) === null || _a === void 0 ? void 0 : _a[0];
        if (uploadedFile &&
            (uploadedFile.type === "image/png" || uploadedFile.type === "image/jpeg")) {
            onFileSelect === null || onFileSelect === void 0 ? void 0 : onFileSelect(uploadedFile);
            const reader = new FileReader();
            reader.onloadend = () => setImage(reader.result);
            reader.readAsDataURL(uploadedFile);
        }
    };
    return (react_1.default.createElement(UploadContainer, null,
        react_1.default.createElement(ImagePreview, { "$imageUrl": image }, !image && (react_1.default.createElement("svg", { width: "64", height: "64", viewBox: "0 0 64 64", fill: "none", xmlns: "http://www.w3.org/2000/svg" },
            react_1.default.createElement("g", { clipPath: "url(#clip0_2412_9890)" },
                react_1.default.createElement("rect", { width: "64", height: "64", rx: "32", fill: "#E1E4EA" }),
                react_1.default.createElement("rect", { width: "64", height: "64", fill: "#E1E4EA" }),
                react_1.default.createElement("path", { opacity: "0.48", d: "M8 28.4573C8 26.69 9.43268 25.2573 11.2 25.2573H35.1996C36.9669 25.2573 38.3996 26.69 38.3996 28.4573V84.4575C38.3996 86.2248 36.9669 87.6575 35.1996 87.6575H11.2C9.43268 87.6575 8 86.2248 8 84.4575V28.4573Z", fill: "white" }),
                react_1.default.createElement("path", { d: "M24 15.9998C24 14.2325 25.4327 12.7998 27.2 12.7998H51.1996C52.9669 12.7998 54.3996 14.2325 54.3996 15.9998V72C54.3996 73.7673 52.9669 75.2 51.1996 75.2H27.2C25.4327 75.2 24 73.7673 24 72V15.9998Z", fill: "white", fillOpacity: "0.8" })),
            react_1.default.createElement("defs", null,
                react_1.default.createElement("clipPath", { id: "clip0_2412_9890" },
                    react_1.default.createElement("rect", { width: "64", height: "64", rx: "32", fill: "white" })))))),
        react_1.default.createElement(InfoWrapper, null,
            react_1.default.createElement(Title, { "$darkmode": darkmode }, "Upload Image"),
            react_1.default.createElement(Subtitle, null, "Min 400x400px, PNG or JPEG"),
            react_1.default.createElement(UploadButton, null,
                "Upload",
                react_1.default.createElement(HiddenInput, { type: "file", accept: "image/png, image/jpeg", onChange: handleImageUpload })))));
};
exports.UploadImage = UploadImage;
