"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Pagination = exports.DoubleLeftArrowIcon = exports.LeftArrowIcon = exports.DoubleRightArrowIcon = exports.RightArrowIcon = exports.SortableIcon = void 0;
const react_1 = __importDefault(require("react"));
const styled_components_1 = __importDefault(require("styled-components"));
const SortableIcon = ({ size = 20, color = "#525866", }) => (react_1.default.createElement("svg", { width: size, height: size, viewBox: "0 0 20 20", fill: "none", xmlns: "http://www.w3.org/2000/svg" },
    react_1.default.createElement("path", { d: "M14.1666 7.91667L9.99992 3.75L5.83325 7.91667H14.1666ZM14.1666 12.0833L9.99992 16.25L5.83325 12.0833H14.1666Z", fill: color })));
exports.SortableIcon = SortableIcon;
const RightArrowIcon = ({ size = 6, color = "#525866", }) => (react_1.default.createElement("svg", { width: size, height: "10", viewBox: "0 0 6 10", fill: "none", xmlns: "http://www.w3.org/2000/svg" },
    react_1.default.createElement("path", { d: "M3.79575 4.99907L0.083252 1.28657L1.14375 0.226074L5.91675 4.99907L1.14375 9.77207L0.083252 8.71157L3.79575 4.99907Z", fill: color })));
exports.RightArrowIcon = RightArrowIcon;
const DoubleRightArrowIcon = ({ size = 10, color = "#525866", }) => (react_1.default.createElement("svg", { width: size, height: size, viewBox: "0 0 10 10", fill: "none", xmlns: "http://www.w3.org/2000/svg" },
    react_1.default.createElement("path", { d: "M9.97517 5.00045L5.66468 0.689941L4.6826 1.67203L8.011 5.00045L4.6826 8.32885L5.66468 9.31093L9.97517 5.00045ZM6.05162 5.00045L1.74112 0.689941L0.759033 1.67203L4.08746 5.00045L0.759033 8.32885L1.74112 9.31093L6.05162 5.00045Z", fill: color })));
exports.DoubleRightArrowIcon = DoubleRightArrowIcon;
const LeftArrowIcon = ({ size = 6, color = "#525866", }) => (react_1.default.createElement("svg", { width: size, height: "10", viewBox: "0 0 6 10", fill: "none", xmlns: "http://www.w3.org/2000/svg" },
    react_1.default.createElement("path", { d: "M2.20425 4.99907L5.91675 8.71157L4.85625 9.77207L0.083252 4.99907L4.85625 0.226074L5.91675 1.28657L2.20425 4.99907Z", fill: color })));
exports.LeftArrowIcon = LeftArrowIcon;
const DoubleLeftArrowIcon = ({ size = 10, color = "#525866", }) => (react_1.default.createElement("svg", { width: size, height: size, viewBox: "0 0 10 10", fill: "none", xmlns: "http://www.w3.org/2000/svg" },
    react_1.default.createElement("path", { d: "M0.0249023 5.00045L4.33536 9.31093L5.31751 8.32885L1.98908 5.00045L5.31751 1.67203L4.33536 0.689941L0.0249023 5.00045ZM3.94842 5.00045L8.2589 9.31093L9.24106 8.32885L5.91265 5.00045L9.24106 1.67203L8.2589 0.689941L3.94842 5.00045Z", fill: color })));
exports.DoubleLeftArrowIcon = DoubleLeftArrowIcon;
const PaginationWrapper = styled_components_1.default.div `
  display: flex;
  justify-content: center;
  align-items: center;
  padding: 8px;
  gap: 8px;
  margin-top: 12px;
  border-radius: 8px;
  padding: 12px;
`;
const PageButton = styled_components_1.default.button `
  width: 32px;
  height: 32px;
  display: flex;
  align-items: center;
  justify-content: center;
  background: ${({ $selected, $darkmode }) => $selected
    ? $darkmode
        ? "#2B303B"
        : "#F5F7FA"
    : $darkmode
        ? "#1A1F2A"
        : "#FFFFFF"};
  border: 1px solid ${({ $darkmode }) => ($darkmode ? "#2B303B" : "#F5F7FA")};
  border-radius: 8px;
  cursor: pointer;
  transition: 0.3s;
  font-size: 14px;
  font-weight: 500;
  color: ${({ $darkmode }) => ($darkmode ? "#E1E4EA" : "#525866")};

  &:hover {
    background: ${({ $darkmode }) => ($darkmode ? "#2B303B" : "#E1E4EA")};
  }
`;
const PaginationButton = styled_components_1.default.button `
  width: 32px;
  height: 32px;
  display: flex;
  align-items: center;
  justify-content: center;
  background: ${({ $darkmode }) => ($darkmode ? "#1A1F2A" : "#FFFFFF")};
  border-radius: 8px;
  cursor: pointer;
  border: transparent;
  color: ${({ $darkmode }) => ($darkmode ? "#E1E4EA" : "#525866")};

  &:disabled {
    opacity: 0.5;
    cursor: not-allowed;
  }
`;
const Pagination = ({ currentPage, totalPages, onPageChange, darkmode = false, }) => {
    return (react_1.default.createElement(PaginationWrapper, { "$darkmode": darkmode },
        react_1.default.createElement(PaginationButton, { onClick: () => onPageChange(1), disabled: currentPage === 1, "$darkmode": darkmode },
            react_1.default.createElement(exports.DoubleLeftArrowIcon, null)),
        react_1.default.createElement(PaginationButton, { onClick: () => onPageChange(currentPage - 1), disabled: currentPage === 1, "$darkmode": darkmode },
            react_1.default.createElement(exports.LeftArrowIcon, null)),
        Array.from({ length: totalPages }, (_, i) => (react_1.default.createElement(PageButton, { key: i, "$selected": currentPage === i + 1, onClick: () => onPageChange(i + 1), "$darkmode": darkmode }, i + 1))),
        react_1.default.createElement(PaginationButton, { onClick: () => onPageChange(currentPage + 1), disabled: currentPage === totalPages, "$darkmode": darkmode },
            react_1.default.createElement(exports.RightArrowIcon, null)),
        react_1.default.createElement(PaginationButton, { onClick: () => onPageChange(totalPages), disabled: currentPage === totalPages, "$darkmode": darkmode },
            react_1.default.createElement(exports.DoubleRightArrowIcon, null))));
};
exports.Pagination = Pagination;
