"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
exports.PieChart = void 0;
const react_1 = __importStar(require("react"));
const chart_js_1 = require("chart.js");
chart_js_1.Chart.register(chart_js_1.DoughnutController, chart_js_1.ArcElement);
const PieChart = ({ data, centerText, largerText, largeTextDown = false, darkmode = false, }) => {
    const chartRef = (0, react_1.useRef)(null);
    const chartInstance = (0, react_1.useRef)(null);
    const fontLinkRef = (0, react_1.useRef)(null);
    (0, react_1.useEffect)(() => {
        if (!document.getElementById("inter-font-link")) {
            const link = document.createElement("link");
            link.id = "inter-font-link";
            link.href =
                "https://fonts.googleapis.com/css2?family=Inter:wght@400;700&display=swap";
            link.rel = "stylesheet";
            document.head.appendChild(link);
            fontLinkRef.current = link;
        }
        const initChart = () => {
            if (!chartRef.current)
                return;
            const ctx = chartRef.current.getContext("2d");
            if (!ctx)
                return;
            if (chartInstance.current) {
                chartInstance.current.destroy();
                chartInstance.current = null;
            }
            const values = data.map((item) => item.value);
            const colors = data.map((item) => item.color);
            const totalFilled = values.reduce((sum, val) => sum + val, 0);
            if (totalFilled > 100) {
                console.error("Total percentage exceeds 100%");
                return;
            }
            values.push(100 - totalFilled);
            colors.push("#D9DCE1");
            const textColor = darkmode === true ? "#FFFFFF" : "#333";
            const centerTextPlugin = {
                id: "centerText",
                afterDraw: (chart) => {
                    const { ctx, width, height } = chart;
                    ctx.save();
                    ctx.fillStyle = textColor;
                    ctx.textAlign = "center";
                    ctx.textBaseline = "middle";
                    const centerX = width / 2;
                    const centerY = height / 1.3;
                    if (largerText) {
                        ctx.font = "bold 30px 'Inter', sans-serif";
                        if (largeTextDown) {
                            ctx.fillText(largerText, centerX, centerY - 20);
                        }
                        else {
                            ctx.fillText(largerText, centerX, centerY - 42);
                        }
                    }
                    ctx.font = "12px 'Inter', sans-serif";
                    if (largeTextDown) {
                        ctx.fillText(centerText || "", centerX, centerY - 50);
                    }
                    else {
                        ctx.fillText(centerText || "", centerX, centerY - 10);
                    }
                    ctx.restore();
                },
            };
            const config = {
                type: "doughnut",
                data: {
                    datasets: [
                        {
                            data: values,
                            backgroundColor: colors,
                            borderWidth: 0,
                        },
                    ],
                },
                options: {
                    rotation: -90,
                    circumference: 180,
                    cutout: "75%",
                    responsive: true,
                    maintainAspectRatio: false,
                    plugins: {
                        tooltip: { enabled: false },
                        legend: { display: false },
                    },
                },
                plugins: [centerTextPlugin],
            };
            chartInstance.current = new chart_js_1.Chart(ctx, config);
        };
        setTimeout(initChart, 200);
        return () => {
            if (chartInstance.current) {
                chartInstance.current.destroy();
                chartInstance.current = null;
            }
        };
    }, [data, centerText, largerText, largeTextDown, darkmode]);
    return (react_1.default.createElement("div", { style: { width: "248px", height: "248px", position: "relative" } },
        react_1.default.createElement("canvas", { ref: chartRef })));
};
exports.PieChart = PieChart;
