"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Table = void 0;
const react_1 = __importStar(require("react"));
const styled_components_1 = __importDefault(require("styled-components"));
const Pagination_1 = require("../pagination/Pagination");
const ROWS_PER_PAGE = 8;
const TableWrapper = styled_components_1.default.div `
  border-radius: 8px;
  padding: 16px;
  width: 100%;
  box-shadow: 0px 1px 2px rgba(10, 13, 20, 0.03);
  overflow-x: auto;
`;
const TableElement = styled_components_1.default.table `
  width: 100%;
  border-collapse: collapse;
  table-layout: auto;
  color: ${({ $darkmode }) => ($darkmode ? "#E1E4EA" : "#525866")};
`;
const TableHead = styled_components_1.default.thead `
  background: ${({ $darkmode }) => ($darkmode ? "#181B25" : "#F5F7FA")};
`;
const TableHeadRow = styled_components_1.default.tr ``;
const TableHeader = styled_components_1.default.th `
  padding: 8px 12px;
  text-align: left;
  font-size: 14px;
  font-weight: 400;
  color: ${({ $darkmode }) => ($darkmode ? "#E1E4EA" : "#525866")};
  border-bottom: 2px solid
    ${({ $darkmode }) => ($darkmode ? "#2B303B" : "#E1E4EA")};
  background: ${({ $darkmode }) => ($darkmode ? "#181B25" : "transparent")};
  white-space: nowrap;
  transition: background 0.3s ease;
`;
const TableHeaderContent = styled_components_1.default.div `
  display: flex;
  align-items: center;
  justify-content: ${({ $sortable }) => $sortable ? "space-between" : "flex-start"};
  gap: 6px;
  width: 100%;
`;
const TableBody = styled_components_1.default.tbody ``;
const TableRow = styled_components_1.default.tr `
  background: ${({ $darkmode }) => ($darkmode ? "#0E121b" : "#FFFFFF")};
  height: 48px;
`;
const TableCell = styled_components_1.default.td `
  padding: 12px;
  font-size: 14px;
  white-space: nowrap;
`;
const Table = ({ columns, data, darkmode = false }) => {
    const [sortedColumn, setSortedColumn] = (0, react_1.useState)(null);
    const [sortOrder, setSortOrder] = (0, react_1.useState)("asc");
    const [currentPage, setCurrentPage] = (0, react_1.useState)(1);
    const handleSort = (column) => {
        const newOrder = sortedColumn === column && sortOrder === "asc" ? "desc" : "asc";
        setSortedColumn(column);
        setSortOrder(newOrder);
    };
    const sortedData = [...data].sort((a, b) => {
        if (!sortedColumn)
            return 0;
        return sortOrder === "asc"
            ? String(a[sortedColumn]).localeCompare(String(b[sortedColumn]))
            : String(b[sortedColumn]).localeCompare(String(a[sortedColumn]));
    });
    const totalPages = Math.ceil(sortedData.length / ROWS_PER_PAGE);
    const paginatedData = sortedData.slice((currentPage - 1) * ROWS_PER_PAGE, currentPage * ROWS_PER_PAGE);
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement(TableWrapper, { "$darkmode": darkmode },
            react_1.default.createElement(TableElement, { "$darkmode": darkmode },
                react_1.default.createElement(TableHead, { "$darkmode": darkmode },
                    react_1.default.createElement(TableHeadRow, null, columns.map((col, index) => (react_1.default.createElement(TableHeader, { key: index, "$sortable": col.sortable, "$darkmode": darkmode, onClick: () => col.sortable && handleSort(col.label) },
                        react_1.default.createElement(TableHeaderContent, { "$sortable": col.sortable },
                            col.label,
                            col.sortable && react_1.default.createElement(Pagination_1.SortableIcon, null))))))),
                react_1.default.createElement(TableBody, null, paginatedData.map((row, rowIndex) => (react_1.default.createElement(TableRow, { key: rowIndex, "$darkmode": darkmode }, columns.map((col, colIndex) => (react_1.default.createElement(TableCell, { key: colIndex }, col.render ? col.render(row) : row[col.label]))))))))),
        react_1.default.createElement(Pagination_1.Pagination, { currentPage: currentPage, totalPages: totalPages, onPageChange: setCurrentPage, darkmode: darkmode })));
};
exports.Table = Table;
